/*
 * Copyright (c) 1998-99 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache 
 *    Project (http://java.apache.org/)."
 *
 * 4. The names "Apache JMeter" and "Java Apache Project" must 
 *    not be used to endorse or promote products derived from this software 
 *    without prior written permission.
 *
 * 5. Products derived from this software may not be called "Apache JMeter"
 *    nor may "Java Apache Project" appear in their names without 
 *    prior written permission of the Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache 
 *    Project (http://java.apache.org/)."
 *    
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Project. For more information
 * on the Java Apache Project please see <http://java.apache.org/>.
 *
 */
 
package org.apache.jmeter.timers;

import java.awt.*;
import java.util.*;
import javax.swing.*;

/**
 * This class implements a random timer with its own panel
 * and fields for value update and user interaction.
 *
 * Since this class does not define the delay() method, is
 * abstract and must be extended to provide full functionality.
 *
 * @author  <a href="mailto:stefano@apache.org">Stefano Mazzocchi</a>
 * @version $Revision: 1.3 $ $Date: 1999/02/24 15:32:45 $
 */
public abstract class RandomTimer extends JPanel implements Timer {

    protected Random random;
    protected long delay = 300;
    protected double range = 100.0;
    
    private JTextField delayField;
    private JTextField rangeField;

    public RandomTimer() {
        this.random = new Random();

        JLabel delayLabel = new JLabel("Average Delay");
        JLabel rangeLabel = new JLabel("Delay Deviation");
        delayField = new JTextField(Long.toString(delay), 6);
        rangeField = new JTextField(Double.toString(range), 6);

        JPanel labelPane = new JPanel();
        labelPane.setLayout(new GridLayout(0, 1));
        labelPane.add(delayLabel);
        labelPane.add(rangeLabel);

        JPanel fieldPane = new JPanel();
        fieldPane.setLayout(new GridLayout(0, 1));
        fieldPane.add(delayField);
        fieldPane.add(rangeField);
        
        this.setLayout(new FlowLayout());
        this.add(labelPane);
        this.add(fieldPane);
    }
 
    public void set() {
        try {
            delay = Long.parseLong(delayField.getText());
            range = Double.valueOf(rangeField.getText()).doubleValue();
        } catch (NumberFormatException ex) {
            error(ex, this);
            this.delayField.setText(Long.toString(delay));
            this.rangeField.setText(Double.toString(range));
        }
    }
    
    public static void error(Exception e, JComponent thrower) {
        JOptionPane.showMessageDialog(thrower, e, "Error", JOptionPane.ERROR_MESSAGE);
    }
}